%define major         11
%define gpgmepp_major 6
%define qgpgme_major  15

%define libname       %mklibname gpgme %{major}
%define libgpgmepp    %mklibname gpgmepp %{gpgmepp_major}
%define develname     %mklibname gpgme -d

%define libqgpgme     %mklibname qgpgme %{qgpgme_major}
%define qdevname      %mklibname qgpgme -d

Summary:	GnuPG Made Easy (GPGME)
Name:		gpgme
Version:	1.17.1
Release:	%mkrel 4
License:	LGPLv2+
Group:		File tools
URL:		https://www.gnupg.org/gpgme.html
Source0:	https://gnupg.org/ftp/gcrypt/gpgme/%{name}-%{version}.tar.xz

## downstream patches
# Don't add extra libs/cflags in gpgme-config/cmake equivalent
Patch1001:      0001-don-t-add-extra-libraries-for-linking.patch
# add -D_FILE_OFFSET_BITS... to gpgme-config, upstreamable
Patch1002:      gpgme-1.3.2-largefile.patch
# Let's fix stupid AX_PYTHON_DEVEL
Patch1003:      0001-fix-stupid-ax_python_devel.patch

# support for Cryptographic Message Syntax protocol
BuildRequires:	gnupg2
BuildRequires:	libassuan-devel
BuildRequires:	libgpg-error-devel
BuildRequires:	libglib2-devel
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Test)
BuildRequires:	doxygen
BuildRequires:	graphviz
# Build dependencies for Python subpackages
BuildRequires:	swig
BuildRequires:	pkgconfig(python3)

%description
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
easier for applications.

%package -n %{libname}
Summary:	GnuPG Made Easy (GPGME)
Group:		System/Libraries
# support for Cryptographic Message Syntax protocol
Requires:	gnupg2
Provides:	%{name} = %{version}-%{release}

%description -n %{libname}
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
easier for applications.

%package -n %{libgpgmepp}
Summary:	GpgME++ - C++ bindings/wrapper for gpgme
Group:		System/Libraries

%description -n %{libgpgmepp}
GpgME++ - C++ bindings/wrapper for gpgme

%package -n %{libqgpgme}
Summary:	GpgME++ - C++ bindings/wrapper for gpgme
Group:		System/Libraries
License:	GPLv2+

%description -n %{libqgpgme}
GpgME++ - C++ bindings/wrapper for gpgme.

%package -n %{develname}
Summary:	GnuPG Made Easy (GPGME) Header files and libraries for development
Group:		Development/Libraries
License:	LGPLv2+
Requires:	%{libname} = %{version}-%{release}
Requires:	%{libgpgmepp} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG easier
for applications.

Install this package if you want to develop applications that will use the
gpgme library for crypto awareness.

%package -n %{qdevname}
Summary:        GnuPG Made Easy (GPGME) Header files and libraries for development
Group:          Development/Libraries
License:        GPLv2+
Requires:       %{libqgpgme} = %{version}-%{release}
Provides:       q%{name}-devel = %{version}-%{release}
Provides:       libq%{name}-devel = %{version}-%{release}


%description -n %{qdevname}
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG easier
for applications.

Install this package if you want to develop applications that will use the
qgpgme library for crypto awareness.

%package -n python3-gpg
Summary:	GnuPG Made Easy (GPGME) bindings for Python 3
Group:		Development/Python
License:	GPLv2+
%{?python_provide:%python_provide python3-gpg}
Requires:	%{libname} = %{version}-%{release}
Provides: python3-gpgme

%description -n python3-gpg
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
easier for applications.

This package provides bindings to %{name} libraries for Python 3.

%package -n python-gpg
Summary:	GnuPG Made Easy (GPGME) bindings for Python 2
Group:		Development/Python
Provides:	python-gpg = %{version}-%{release}
Provides:	python-gpgme
Requires:	%{libname} = %{version}-%{release}

%description -n python-gpg
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
easier for applications.

This package provides bindings to %{name} libraries for Python 2.

%prep
%setup -q
%apply_patches

# Force GPG2
find -type f -name Makefile\* -exec sed -i -e 's|GPG = gpg2\?|GPG = gpg2|' {} ';'

sed -i 's/3.8/%{python3_version}/g' configure configure.ac

%build
autoreconf -fiv
export PATH=%{_qt5_bindir}:$PATH

# Fix qgpgme build on 32bit arches
export CPPFLAGS='-D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'

%configure2_5x \
	--enable-languages=cpp,qt,python,cl \
	--disable-static \
	--disable-gpgsm-test \
	--with-libassuan-prefix=%{_prefix}
%make_build

%install
%make_install

#we don't want these
find %{buildroot} -name "*.la" -delete

# autofoo installs useless stuff for uninstall
rm -vf %{buildroot}%{python3_sitelib}/gpg/install_files.txt

%files -n %{libname}
%{_libdir}/libgpgme.so.%{major}*

%files -n %{libgpgmepp}
%doc lang/cpp/README
%{_libdir}/libgpgmepp.so.%{gpgmepp_major}*

%files -n %{libqgpgme}
%{_libdir}/libqgpgme.so.%{qgpgme_major}*

%files -n %{develname}
%{_bindir}/gpgme-config
%{_bindir}/gpgme-json
%{_bindir}/gpgme-tool
%{_libdir}/libgpgme.so
%{_libdir}/libgpgmepp.so
%{_libdir}/pkgconfig/gpgme.pc
%{_libdir}/pkgconfig/gpgme-glib.pc
%{_datadir}/aclocal/*.m4
%{_includedir}/gpgme++/
%{_includedir}/gpgme.h
%{_infodir}/gpgme.info*
%dir %{_datadir}/common-lisp/source/gpgme
%{_datadir}/common-lisp/source/gpgme/gpgme-package.lisp
%{_datadir}/common-lisp/source/gpgme/gpgme.asd
%{_datadir}/common-lisp/source/gpgme/gpgme.lisp
%{_datadir}/common-lisp/source/gpgme/gpgme-grovel.lisp
%{_libdir}/cmake/Gpgmepp/

%files -n %{qdevname}
%{_includedir}/QGpgME/
%{_includedir}/qgpgme/
%{_libdir}/cmake/QGpgme/
%{_libdir}/libqgpgme.so

%files -n python3-gpg
%doc lang/python/README
%{python3_sitearch}/gpg-*.egg-info
%{python3_sitearch}/gpg/

%files -n python-gpg
%doc lang/python/README
%{python2_sitearch}/gpg-*.egg-info
%{python2_sitearch}/gpg/

%changelog
* Sun Jun 26 2022 TerryN <terryn94 at gmail.com> 1.17.1-4pclos2022
- rebuild for python 3.10

* Sat Jun 25 2022 tex - 1.17.1-3pclos2022
- fix python pkg dependencies

* Thu Jun 23 2022 tex - 1.17.1-2pclos2022
- fix spec file

* Wed Jun 22 2022 yodelu - 1.17.1-1pclos2022
- update

* Wed Sep 22 2021 tex - 1.16.0-2pclos2021
- rebuild against updates

* Wed Jun 30 2021 tex - 1.16.0-1pclos2021
- new version

* Sun Jan 10 2021 tex - 1.15.1-1pclos2021
- new version

* Fri Oct 09 2020 tex - 1.14.0-2pclos2020
- rebuild against updates

* Sat Jul 18 2020 ghostbunny <ghostbunny at gmx dot de> 1.14.0-1pclos2020
- 1.14.0

* Fri Jul 05 2019 tex - 1.13.1-1pclos2019
- new version

* Sat Apr 13 2019 tex 1.13.0-1pclos2019
- new version: 1.13.0
